<?php declare(strict_types=1);

/**
 * Plugin Name: Exclusion Query
 * Description: OpenContent query with exclusion of elements in List.
 * Version: 0.0.1
 * Author: Naviga Web Team
 * Author URI: https://navigaglobal.com/web
 * Text Domain: ew_exclusion_query
 */

use Everyware\ProjectPlugin\Components\WidgetManager;
use Everyware\ProjectPlugin\Helpers\FileReader;
use Everyware\ProjectPlugin\TwigSetup;
use Everyware\Widget\ExclusionQuery\ExclusionQueryWidget;

TwigSetup::registerTwigFolder('ew-exclusion-query', __DIR__ . '/src/templates');

ExclusionQueryWidget::setInfoManager(new FileReader(__FILE__));

WidgetManager::register(ExclusionQueryWidget::class);

add_action( 'admin_enqueue_scripts', 'enqueue_exclusion_query_widget_scripts' );
function enqueue_exclusion_query_widget_scripts() {
    wp_enqueue_script( 'exclusion_ajax_query', plugin_dir_url(__FILE__) . 'assets/js/exclusion_ajax_query.js', ['jquery-core']);
}


add_action( 'wp_ajax_exclusion_oc_query', 'exclusion_oc_ajax_query' );
/**
 * Runs OC query for "test query" button on widget config panel
 */
function exclusion_oc_ajax_query() {
    $obj_count = 0;
    $oc_api = new OcAPI();
    if ( isset( $_POST['query'] ) && $_POST['query'] !== "" ) {
        $query = stripcslashes( trim( $_POST['query'] ) );

        $start = absint( $_POST['oc_query_start'] );
        $limit = absint( $_POST['oc_query_limit'] );
        $sort  = $_POST['oc_query_sort'];
        $property = $_POST['oc_query_property'];

        // Use manual search so we can use specific properties in response
        $result = $oc_api->search([
            'q' => $query,
            'sort.name' => $sort,
            'limit' => $limit,
            'start' => $start > 0 ? $start - 1 : $start,
            'properties'    => [$property]
        ], true, false);

        unset($result['facet'], $result['hits'], $result['duration']);

        foreach ($result as $object) {
            // Empty array if property doesn't exist on object
            $obj_count += count($object->get($property));
        }
    } else {
        $result = array( __( 'Error', 'every' ) => __( 'Empty or invalid query', 'every' ) );
    }

    //generate the response
    $response = json_encode( ['Excluded items' => $obj_count ] );

    // response output
    echo $response;

    // IMPORTANT: don't forget to "exit"
    exit;
}